/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Used for configuring virtual scrolling:
 * * [AutoComplete virtualization]({% slug virtualization_autocomplete %})
 * * [ComboBox virtualization]({% slug virtualization_combobox %})
 * * [DropDownList virtualization]({% slug virtualization_ddl %})
 * * [MultiSelect virtualization]({% slug virtualization_multiselect %})
 *
 * @example
 * ```ts
 * _@Component({
 * selector: 'my-app',
 * template: `
 *  <kendo-dropdownlist [data]="listItems" [virtual]="{ itemHeight: 28, pageSize: 10 }">
 *  </kendo-dropdownlist>
 * `
 * })
 * class AppComponent {
 *   public listItems: Array<string> = ["Item 1", "Item 2", "Item 3", "Item 4"];
 * }
 * ```
 */
export interface VirtualizationSettings {
    /**
     * Sets the height of the items.
     */
    itemHeight: number;
    /**
     * Sets the amount of items that will be rendered in the DOM.
     */
    pageSize?: number;
    /**
     * @hidden
     * The total amount of items in the dataset.
     */
    total?: number;
    /**
     * @hidden
     * Defines the number of records that will be skipped.
     */
    skip?: number;
}
/**
 * @hidden
 */
export declare const normalizeVirtualizationSettings: (settings: boolean | VirtualizationSettings, defaultOverrides?: VirtualizationSettings) => VirtualizationSettings;
