/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import * as i0 from "@angular/core";
import * as i1 from "./autocomplete/autocomplete.component";
import * as i2 from "./common/templates/fixed-group-template.directive";
import * as i3 from "./common/templates/footer-template.directive";
import * as i4 from "./common/templates/group-template.directive";
import * as i5 from "./common/templates/header-template.directive";
import * as i6 from "./common/templates/item-template.directive";
import * as i7 from "./common/templates/no-data-template.directive";
import * as i8 from "./common/filtering/filter.directive";
import * as i9 from "./common/localization/custom-messages.component";
import * as i10 from "@progress/kendo-angular-common";
import * as i11 from "./comboboxes/combobox.component";
import * as i12 from "./comboboxes/multicolumncombobox.component";
import * as i13 from "./comboboxes/combobox-column/combobox-column.component";
import * as i14 from "./comboboxes/combobox-column/column-header-template.directive";
import * as i15 from "./comboboxes/combobox-column/column-cell-template.directive";
import * as i16 from "./dropdownlist/dropdownlist.component";
import * as i17 from "./common/templates/value-template.directive";
import * as i18 from "./multiselect/multiselect.component";
import * as i19 from "./multiselect/summary-tag.directive";
import * as i20 from "./common/templates/custom-item-template.directive";
import * as i21 from "./common/templates/group-tag-template.directive";
import * as i22 from "./common/templates/tag-template.directive";
import * as i23 from "./dropdowntrees/dropdowntree.component";
import * as i24 from "./dropdowntrees/data-binding/dropdowntree/flat-binding.directive";
import * as i25 from "./dropdowntrees/data-binding/dropdowntree/hierarchy-binding.directive";
import * as i26 from "./dropdowntrees/expanded-state/expand.directive";
import * as i27 from "./dropdowntrees/templates/node-template.directive";
import * as i28 from "./dropdowntrees/multiselecttree.component";
import * as i29 from "./dropdowntrees/data-binding/multiselecttree/flat-binding.directive";
import * as i30 from "./dropdowntrees/data-binding/multiselecttree/hierarchy-binding.directive";
import * as i31 from "./dropdowntrees/summary-tag/summary-tag.directive";
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the Dropdowns components.
 *
 * @example
 *
 * ```ts-no-run
 * // Import the Dropdowns module
 * import { DropDownsModule } from '@progress/kendo-angular-dropdowns';
 *
 * // The browser platform with a compiler
 * import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
 *
 * import { NgModule } from '@angular/core';
 *
 * // Import the app component
 * import { AppComponent } from './app.component';
 *
 * // Define the app module
 * _@NgModule({
 *     declarations: [AppComponent], // declare the app component
 *     imports:      [BrowserModule, DropDownsModule], // import the Dropdowns module
 *     bootstrap:    [AppComponent]
 * })
 * export class AppModule {}
 *
 * // Compile and launch the module
 * platformBrowserDynamic().bootstrapModule(AppModule);
 *
 * ```
 */
export declare class DropDownsModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<DropDownsModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<DropDownsModule, never, [typeof i1.AutoCompleteComponent, typeof i2.FixedGroupTemplateDirective, typeof i3.FooterTemplateDirective, typeof i4.GroupTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i6.ItemTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i8.FilterDirective, typeof i9.CustomMessagesComponent, typeof i10.SuffixTemplateDirective, typeof i10.PrefixTemplateDirective, typeof i10.SeparatorComponent, typeof i11.ComboBoxComponent, typeof i2.FixedGroupTemplateDirective, typeof i3.FooterTemplateDirective, typeof i4.GroupTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i6.ItemTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i8.FilterDirective, typeof i9.CustomMessagesComponent, typeof i10.SuffixTemplateDirective, typeof i10.PrefixTemplateDirective, typeof i10.SeparatorComponent, typeof i12.MultiColumnComboBoxComponent, typeof i13.ComboBoxColumnComponent, typeof i14.ColumnHeaderTemplateDirective, typeof i15.ColumnCellTemplateDirective, typeof i2.FixedGroupTemplateDirective, typeof i3.FooterTemplateDirective, typeof i4.GroupTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i6.ItemTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i8.FilterDirective, typeof i9.CustomMessagesComponent, typeof i10.SuffixTemplateDirective, typeof i10.PrefixTemplateDirective, typeof i10.SeparatorComponent, typeof i16.DropDownListComponent, typeof i2.FixedGroupTemplateDirective, typeof i3.FooterTemplateDirective, typeof i4.GroupTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i6.ItemTemplateDirective, typeof i17.ValueTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i8.FilterDirective, typeof i9.CustomMessagesComponent, typeof i18.MultiSelectComponent, typeof i19.SummaryTagDirective, typeof i20.CustomItemTemplateDirective, typeof i2.FixedGroupTemplateDirective, typeof i3.FooterTemplateDirective, typeof i4.GroupTemplateDirective, typeof i21.GroupTagTemplateDirective, typeof i22.TagTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i6.ItemTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i8.FilterDirective, typeof i9.CustomMessagesComponent, typeof i10.SuffixTemplateDirective, typeof i10.PrefixTemplateDirective, typeof i10.SeparatorComponent, typeof i23.DropDownTreeComponent, typeof i24.DropDownTreeFlatBindingDirective, typeof i25.DropDownTreeHierarchyBindingDirective, typeof i26.DropDownTreesExpandDirective, typeof i27.NodeTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i3.FooterTemplateDirective, typeof i17.ValueTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i9.CustomMessagesComponent, typeof i28.MultiSelectTreeComponent, typeof i29.MultiSelectTreeFlatBindingDirective, typeof i30.MultiSelectTreeHierarchyBindingDirective, typeof i26.DropDownTreesExpandDirective, typeof i27.NodeTemplateDirective, typeof i31.MultiSelectTreeSummaryTagDirective, typeof i21.GroupTagTemplateDirective, typeof i22.TagTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i3.FooterTemplateDirective, typeof i17.ValueTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i9.CustomMessagesComponent, typeof i10.PrefixTemplateDirective, typeof i10.SuffixTemplateDirective, typeof i10.SeparatorComponent], [typeof i1.AutoCompleteComponent, typeof i2.FixedGroupTemplateDirective, typeof i3.FooterTemplateDirective, typeof i4.GroupTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i6.ItemTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i8.FilterDirective, typeof i9.CustomMessagesComponent, typeof i10.SuffixTemplateDirective, typeof i10.PrefixTemplateDirective, typeof i10.SeparatorComponent, typeof i11.ComboBoxComponent, typeof i2.FixedGroupTemplateDirective, typeof i3.FooterTemplateDirective, typeof i4.GroupTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i6.ItemTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i8.FilterDirective, typeof i9.CustomMessagesComponent, typeof i10.SuffixTemplateDirective, typeof i10.PrefixTemplateDirective, typeof i10.SeparatorComponent, typeof i12.MultiColumnComboBoxComponent, typeof i13.ComboBoxColumnComponent, typeof i14.ColumnHeaderTemplateDirective, typeof i15.ColumnCellTemplateDirective, typeof i2.FixedGroupTemplateDirective, typeof i3.FooterTemplateDirective, typeof i4.GroupTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i6.ItemTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i8.FilterDirective, typeof i9.CustomMessagesComponent, typeof i10.SuffixTemplateDirective, typeof i10.PrefixTemplateDirective, typeof i10.SeparatorComponent, typeof i16.DropDownListComponent, typeof i2.FixedGroupTemplateDirective, typeof i3.FooterTemplateDirective, typeof i4.GroupTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i6.ItemTemplateDirective, typeof i17.ValueTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i8.FilterDirective, typeof i9.CustomMessagesComponent, typeof i18.MultiSelectComponent, typeof i19.SummaryTagDirective, typeof i20.CustomItemTemplateDirective, typeof i2.FixedGroupTemplateDirective, typeof i3.FooterTemplateDirective, typeof i4.GroupTemplateDirective, typeof i21.GroupTagTemplateDirective, typeof i22.TagTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i6.ItemTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i8.FilterDirective, typeof i9.CustomMessagesComponent, typeof i10.SuffixTemplateDirective, typeof i10.PrefixTemplateDirective, typeof i10.SeparatorComponent, typeof i23.DropDownTreeComponent, typeof i24.DropDownTreeFlatBindingDirective, typeof i25.DropDownTreeHierarchyBindingDirective, typeof i26.DropDownTreesExpandDirective, typeof i27.NodeTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i3.FooterTemplateDirective, typeof i17.ValueTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i9.CustomMessagesComponent, typeof i28.MultiSelectTreeComponent, typeof i29.MultiSelectTreeFlatBindingDirective, typeof i30.MultiSelectTreeHierarchyBindingDirective, typeof i26.DropDownTreesExpandDirective, typeof i27.NodeTemplateDirective, typeof i31.MultiSelectTreeSummaryTagDirective, typeof i21.GroupTagTemplateDirective, typeof i22.TagTemplateDirective, typeof i5.HeaderTemplateDirective, typeof i3.FooterTemplateDirective, typeof i17.ValueTemplateDirective, typeof i7.NoDataTemplateDirective, typeof i9.CustomMessagesComponent, typeof i10.PrefixTemplateDirective, typeof i10.SuffixTemplateDirective, typeof i10.SeparatorComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<DropDownsModule>;
}
